@@ -82,6 +82,7 @@ printProgress(void) {
   printf("Average Speed: %.1f w/s. ",
 	 nrprocessed/difftime(currentTime,startTime));
   printf("Current Word: '%s'\n",str);
+  fflush(stdout);
   nrprocessed = 0;
   startTime = time(NULL);
   return false;
@@ -92,8 +93,8 @@ printProgress(void) {
  * switching between keys
  */
 static unsigned int
-initEncKeyWorkSpace(const int revision, const bool encMetaData, 
-		    const int permissions, const uint8_t *ownerkey, 
+initEncKeyWorkSpace(const int revision, const bool encMetaData,
+		    const int permissions, const uint8_t *ownerkey,
 		    const uint8_t *fileID, const unsigned int fileIDLen) {
   /** 
    *   Algorithm 3.2 Computing an encryption key (PDF Reference, v 1.6, p.101)
@@ -506,8 +507,8 @@ cleanPDFCrack(void) {
 */
 bool
 initPDFCrack(const EncData *e, const uint8_t *upw, const bool user,
-	     const char *wl, const passwordMethod pm, FILE *file, 
-	     const char *cs, const unsigned int minPw, 
+	     const char *wl, const passwordMethod pm, FILE *file,
+	     const char *cs, const unsigned int minPw,
 	     const unsigned int maxPw, const bool perm) {
   uint8_t buf[128];
   unsigned int upwlen;
@@ -578,7 +579,7 @@ initPDFCrack(const EncData *e, const uint8_t *upw, const bool user,
 static const char string_PRVPL[] = 
   "PDF: %d.%d\nR: %d\nV: %d\nP: %d\nL: %d\n"
   "MetaData: %d\nFileID(%d):";
-static const char string_FILTER[] = "\nFilter(%d): ";
+static const char string_FILTER[] = "\nFilter(%zu): ";
 static const char string_UUPWP[] = 
   "\nUser: %d\nUserPw: %d\nPermutate: %d\n";
 
